# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import ComputeResource
from pyVmomi.vim import Datacenter
from pyVmomi.vim import DistributedVirtualSwitch
from pyVmomi.vim import HostSystem
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import ResourcePool
from pyVmomi.vim import StoragePod
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.cluster import ConfigSpec
from pyVmomi.vim.cluster import ConfigSpecEx

from pyVmomi.vim.host import ConnectSpec

from pyVmomi.vim.vm import ConfigSpec

class Folder(ManagedEntity):
   class DesiredHostState(Enum):
      maintenance: ClassVar['DesiredHostState'] = 'maintenance'
      non_maintenance: ClassVar['DesiredHostState'] = 'non_maintenance'

   class NewHostSpec(DynamicData):
      hostCnxSpec: ConnectSpec
      esxLicense: Optional[str] = None

   class FailedHostResult(DynamicData):
      hostName: Optional[str] = None
      host: Optional[HostSystem] = None
      context: LocalizableMessage
      fault: MethodFault

   class BatchAddStandaloneHostsResult(DynamicData):
      addedHosts: list[HostSystem] = []
      hostsFailedInventoryAdd: list[FailedHostResult] = []

   class BatchAddHostsToClusterResult(DynamicData):
      hostsAddedToCluster: list[HostSystem] = []
      hostsFailedInventoryAdd: list[FailedHostResult] = []
      hostsFailedMoveToCluster: list[FailedHostResult] = []

   class ExternallyManagedFolderType(Enum):
      PROJECT_ROOT: ClassVar['ExternallyManagedFolderType'] = 'PROJECT_ROOT'
      PROJECT: ClassVar['ExternallyManagedFolderType'] = 'PROJECT'
      VPC_ROOT: ClassVar['ExternallyManagedFolderType'] = 'VPC_ROOT'
      VPC: ClassVar['ExternallyManagedFolderType'] = 'VPC'
      SUBNET: ClassVar['ExternallyManagedFolderType'] = 'SUBNET'
      SEGMENT: ClassVar['ExternallyManagedFolderType'] = 'SEGMENT'
      SUPERVISOR: ClassVar['ExternallyManagedFolderType'] = 'SUPERVISOR'
      VSPHERE_POD: ClassVar['ExternallyManagedFolderType'] = 'VSPHERE_POD'

   class ExternallyManagedFolderInfo(DynamicData):
      id: str
      type: str

   @property
   def childType(self) -> list[type]: ...
   @property
   def childEntity(self) -> list[ManagedEntity]: ...
   @property
   def namespace(self) -> Optional[str]: ...
   @property
   def externallyManagedFolderInfo(self) -> Optional[ExternallyManagedFolderInfo]: ...

   def CreateFolder(self, name: str) -> Folder: ...
   def MoveInto(self, list: list[ManagedEntity]) -> Task: ...
   def CreateVm(self, config: ConfigSpec, pool: ResourcePool, host: Optional[HostSystem]) -> Task: ...
   def RegisterVm(self, path: str, name: Optional[str], asTemplate: bool, pool: Optional[ResourcePool], host: Optional[HostSystem]) -> Task: ...
   def CreateCluster(self, name: str, spec: ConfigSpec) -> ClusterComputeResource: ...
   def CreateClusterEx(self, name: str, spec: ConfigSpecEx) -> ClusterComputeResource: ...
   def AddStandaloneHost(self, spec: ConnectSpec, compResSpec: Optional[ComputeResource.ConfigSpec], addConnected: bool, license: Optional[str]) -> Task: ...
   def CreateDatacenter(self, name: str) -> Datacenter: ...
   def UnregisterAndDestroy(self) -> Task: ...
   def CreateDistributedVirtualSwitch(self, spec: DistributedVirtualSwitch.CreateSpec) -> Task: ...
   def CreateStoragePod(self, name: str) -> StoragePod: ...
   def BatchAddStandaloneHosts(self, newHosts: list[NewHostSpec], compResSpec: Optional[ComputeResource.ConfigSpec], addConnected: bool) -> Task: ...
   def BatchAddHostsToCluster(self, cluster: ClusterComputeResource, newHosts: list[NewHostSpec], existingHosts: list[HostSystem], compResSpec: Optional[ComputeResource.ConfigSpec], desiredState: Optional[str]) -> Task: ...



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import PropertyPath

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import DynamicProperty
from pyVmomi.vmodl import MethodFault

class PropertyCollector(ManagedObject):
   class FilterSpec(DynamicData):
      propSet: list[PropertySpec] = []
      objectSet: list[ObjectSpec] = []
      reportMissingObjectsInResults: Optional[bool] = None

   class PropertySpec(DynamicData):
      type: type
      all: Optional[bool] = None
      pathSet: list[PropertyPath] = []

   class ObjectSpec(DynamicData):
      obj: ManagedObject
      skip: Optional[bool] = None
      selectSet: list[SelectionSpec] = []

   class SelectionSpec(DynamicData):
      name: Optional[str] = None

   class TraversalSpec(SelectionSpec):
      type: type
      path: PropertyPath
      skip: Optional[bool] = None
      selectSet: list[SelectionSpec] = []

   class Filter(ManagedObject):
      @property
      def spec(self) -> FilterSpec: ...
      @property
      def partialUpdates(self) -> bool: ...

      def Destroy(self) -> NoReturn: ...

   class ObjectContent(DynamicData):
      obj: ManagedObject
      propSet: list[DynamicProperty] = []
      missingSet: list[MissingProperty] = []

   class UpdateSet(DynamicData):
      version: str
      filterSet: list[FilterUpdate] = []
      truncated: Optional[bool] = None

   class FilterUpdate(DynamicData):
      filter: Filter
      objectSet: list[ObjectUpdate] = []
      missingSet: list[MissingObject] = []

   class ObjectUpdate(DynamicData):
      class Kind(Enum):
         modify: ClassVar['Kind'] = 'modify'
         enter: ClassVar['Kind'] = 'enter'
         leave: ClassVar['Kind'] = 'leave'

      kind: Kind
      obj: ManagedObject
      changeSet: list[Change] = []
      missingSet: list[MissingProperty] = []

   class Change(DynamicData):
      class Op(Enum):
         add: ClassVar['Op'] = 'add'
         remove: ClassVar['Op'] = 'remove'
         assign: ClassVar['Op'] = 'assign'
         indirectRemove: ClassVar['Op'] = 'indirectRemove'

      name: PropertyPath
      op: Op
      val: Optional[object] = None

   class MissingProperty(DynamicData):
      path: PropertyPath
      fault: MethodFault

   class MissingObject(DynamicData):
      obj: ManagedObject
      fault: MethodFault

   class WaitOptions(DynamicData):
      maxWaitSeconds: Optional[int] = None
      maxObjectUpdates: Optional[int] = None

   class RetrieveOptions(DynamicData):
      maxObjects: Optional[int] = None

   class RetrieveResult(DynamicData):
      token: Optional[str] = None
      objects: list[ObjectContent] = []

   @property
   def filter(self) -> list[Filter]: ...

   def CreateFilter(self, spec: FilterSpec, partialUpdates: bool) -> Filter: ...
   def RetrieveContents(self, specSet: list[FilterSpec]) -> list[ObjectContent]: ...
   def CheckForUpdates(self, version: Optional[str]) -> Optional[UpdateSet]: ...
   def WaitForUpdates(self, version: Optional[str]) -> UpdateSet: ...
   def CancelWaitForUpdates(self) -> NoReturn: ...
   def WaitForUpdatesEx(self, version: Optional[str], options: Optional[WaitOptions]) -> Optional[UpdateSet]: ...
   def RetrievePropertiesEx(self, specSet: list[FilterSpec], options: RetrieveOptions) -> Optional[RetrieveResult]: ...
   def ContinueRetrievePropertiesEx(self, token: str) -> RetrieveResult: ...
   def CancelRetrievePropertiesEx(self, token: str) -> NoReturn: ...
   def CreatePropertyCollector(self) -> PropertyCollector: ...
   def Destroy(self) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import HostBusAdapter
from pyVmomi.vim.host import ScsiLun
from pyVmomi.vim.host import TargetTransport

class ScsiTopology(DynamicData):
   class Interface(DynamicData):
      key: str
      adapter: HostBusAdapter
      target: list[Target] = []

   class Target(DynamicData):
      key: str
      target: int
      lun: list[Lun] = []
      transport: Optional[TargetTransport] = None

   class Lun(DynamicData):
      key: str
      lun: int
      scsiLun: ScsiLun

   adapter: list[Interface] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import HostSystem
from pyVmomi.vim import KeyValue
from pyVmomi.vim import LicenseAssignmentManager

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import KeyAnyValue

class LicenseManager(ManagedObject):
   class LicenseState(Enum):
      initializing: ClassVar['LicenseState'] = 'initializing'
      normal: ClassVar['LicenseState'] = 'normal'
      marginal: ClassVar['LicenseState'] = 'marginal'
      fault: ClassVar['LicenseState'] = 'fault'

   class LicenseKey(Enum):
      esxFull: ClassVar['LicenseKey'] = 'esxFull'
      esxVmtn: ClassVar['LicenseKey'] = 'esxVmtn'
      esxExpress: ClassVar['LicenseKey'] = 'esxExpress'
      san: ClassVar['LicenseKey'] = 'san'
      iscsi: ClassVar['LicenseKey'] = 'iscsi'
      nas: ClassVar['LicenseKey'] = 'nas'
      vsmp: ClassVar['LicenseKey'] = 'vsmp'
      backup: ClassVar['LicenseKey'] = 'backup'
      vc: ClassVar['LicenseKey'] = 'vc'
      vcExpress: ClassVar['LicenseKey'] = 'vcExpress'
      esxHost: ClassVar['LicenseKey'] = 'esxHost'
      gsxHost: ClassVar['LicenseKey'] = 'gsxHost'
      serverHost: ClassVar['LicenseKey'] = 'serverHost'
      drsPower: ClassVar['LicenseKey'] = 'drsPower'
      vmotion: ClassVar['LicenseKey'] = 'vmotion'
      drs: ClassVar['LicenseKey'] = 'drs'
      das: ClassVar['LicenseKey'] = 'das'

   class LicenseSource(DynamicData):
      pass

   class LicenseServer(LicenseSource):
      licenseServer: str

   class LocalLicense(LicenseSource):
      licenseKeys: str

   class EvaluationLicense(LicenseSource):
      remainingHours: Optional[long] = None

   class FeatureInfo(DynamicData):
      class CostUnit(Enum):
         host: ClassVar['CostUnit'] = 'host'
         cpuCore: ClassVar['CostUnit'] = 'cpuCore'
         cpuPackage: ClassVar['CostUnit'] = 'cpuPackage'
         server: ClassVar['CostUnit'] = 'server'
         vm: ClassVar['CostUnit'] = 'vm'

      class State(Enum):
         enabled: ClassVar['State'] = 'enabled'
         disabled: ClassVar['State'] = 'disabled'
         optional: ClassVar['State'] = 'optional'

      class SourceRestriction(Enum):
         unrestricted: ClassVar['SourceRestriction'] = 'unrestricted'
         served: ClassVar['SourceRestriction'] = 'served'
         file: ClassVar['SourceRestriction'] = 'file'

      key: str
      featureName: str
      featureDescription: Optional[str] = None
      state: Optional[State] = None
      costUnit: str
      sourceRestriction: Optional[str] = None
      dependentKey: list[str] = []
      edition: Optional[bool] = None
      expiresOn: Optional[datetime] = None

   class ReservationInfo(DynamicData):
      class State(Enum):
         notUsed: ClassVar['State'] = 'notUsed'
         noLicense: ClassVar['State'] = 'noLicense'
         unlicensedUse: ClassVar['State'] = 'unlicensedUse'
         licensed: ClassVar['State'] = 'licensed'

      key: str
      state: State
      required: int

   class AvailabilityInfo(DynamicData):
      feature: FeatureInfo
      total: int
      available: int

   class DiagnosticInfo(DynamicData):
      sourceLastChanged: datetime
      sourceLost: str
      sourceLatency: float
      licenseRequests: str
      licenseRequestFailures: str
      licenseFeatureUnknowns: str
      opState: LicenseState
      lastStatusUpdate: datetime
      opFailureMessage: str

   class LicenseUsageInfo(DynamicData):
      source: LicenseSource
      sourceAvailable: bool
      reservationInfo: list[ReservationInfo] = []
      featureInfo: list[FeatureInfo] = []

   class EvaluationInfo(DynamicData):
      properties: list[KeyAnyValue] = []

   class LicensableResourceInfo(DynamicData):
      class ResourceKey(Enum):
         numCpuPackages: ClassVar['ResourceKey'] = 'numCpuPackages'
         numCpuCores: ClassVar['ResourceKey'] = 'numCpuCores'
         memorySize: ClassVar['ResourceKey'] = 'memorySize'
         memoryForVms: ClassVar['ResourceKey'] = 'memoryForVms'
         numVmsStarted: ClassVar['ResourceKey'] = 'numVmsStarted'
         numVmsStarting: ClassVar['ResourceKey'] = 'numVmsStarting'
         vsanCapacity: ClassVar['ResourceKey'] = 'vsanCapacity'

      resource: list[KeyAnyValue] = []

   class LicenseInfo(DynamicData):
      licenseKey: str
      editionKey: str
      name: str
      total: int
      used: Optional[int] = None
      costUnit: str
      properties: list[KeyAnyValue] = []
      labels: list[KeyValue] = []

   @property
   def source(self) -> LicenseSource: ...
   @property
   def sourceAvailable(self) -> bool: ...
   @property
   def diagnostics(self) -> Optional[DiagnosticInfo]: ...
   @property
   def featureInfo(self) -> list[FeatureInfo]: ...
   @property
   def licensedEdition(self) -> str: ...
   @property
   def licenses(self) -> list[LicenseInfo]: ...
   @property
   def licenseAssignmentManager(self) -> Optional[LicenseAssignmentManager]: ...
   @property
   def evaluation(self) -> EvaluationInfo: ...

   def QuerySupportedFeatures(self, host: Optional[HostSystem]) -> list[FeatureInfo]: ...
   def QuerySourceAvailability(self, host: Optional[HostSystem]) -> list[AvailabilityInfo]: ...
   def QueryUsage(self, host: Optional[HostSystem]) -> LicenseUsageInfo: ...
   def SetEdition(self, host: Optional[HostSystem], featureKey: Optional[str]) -> NoReturn: ...
   def CheckFeature(self, host: Optional[HostSystem], featureKey: str) -> bool: ...
   def Enable(self, host: Optional[HostSystem], featureKey: str) -> bool: ...
   def Disable(self, host: Optional[HostSystem], featureKey: str) -> bool: ...
   def ConfigureSource(self, host: Optional[HostSystem], licenseSource: LicenseSource) -> NoReturn: ...
   def UpdateLicense(self, licenseKey: str, labels: list[KeyValue]) -> LicenseInfo: ...
   def AddLicense(self, licenseKey: str, labels: list[KeyValue]) -> LicenseInfo: ...
   def RemoveLicense(self, licenseKey: str) -> NoReturn: ...
   def DecodeLicense(self, licenseKey: str) -> LicenseInfo: ...
   def UpdateLabel(self, licenseKey: str, labelKey: str, labelValue: str) -> NoReturn: ...
   def RemoveLabel(self, licenseKey: str, labelKey: str) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.event import CustomizationEvent

class CustomizationFailed(CustomizationEvent):
   class ReasonCode(Enum):
      userDefinedScriptDisabled: ClassVar['ReasonCode'] = 'userDefinedScriptDisabled'
      customizationDisabled: ClassVar['ReasonCode'] = 'customizationDisabled'
      rawDataIsNotSupported: ClassVar['ReasonCode'] = 'rawDataIsNotSupported'
      wrongMetadataFormat: ClassVar['ReasonCode'] = 'wrongMetadataFormat'

   reason: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import BoolPolicy
from pyVmomi.vim import DistributedVirtualSwitch
from pyVmomi.vim import InheritablePolicy
from pyVmomi.vim import IntPolicy
from pyVmomi.vim import NumericRange
from pyVmomi.vim import StringPolicy
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.dvs import DistributedVirtualPort
from pyVmomi.vim.dvs import DistributedVirtualPortgroup
from pyVmomi.vim.dvs import HostMember

from pyVmomi.vim.host import LinkDiscoveryProtocolConfig

class VmwareDistributedVirtualSwitch(DistributedVirtualSwitch):
   class FeatureCapability(DistributedVirtualSwitch.FeatureCapability):
      vspanSupported: Optional[bool] = None
      lldpSupported: Optional[bool] = None
      ipfixSupported: Optional[bool] = None
      ipfixCapability: Optional[IpfixFeatureCapability] = None
      multicastSnoopingSupported: Optional[bool] = None
      vspanCapability: Optional[VspanFeatureCapability] = None
      lacpCapability: Optional[LacpFeatureCapability] = None
      dpuCapability: Optional[DpuFeatureCapability] = None
      nsxSupported: Optional[bool] = None
      mtuCapability: Optional[MtuCapability] = None
      realTimeConfigSupported: Optional[bool] = None

   class IpfixFeatureCapability(DynamicData):
      ipfixSupported: Optional[bool] = None
      ipv6ForIpfixSupported: Optional[bool] = None
      observationDomainIdSupported: Optional[bool] = None

   class LacpFeatureCapability(DynamicData):
      lacpSupported: Optional[bool] = None
      multiLacpGroupSupported: Optional[bool] = None
      lacpFastModeSupported: Optional[bool] = None

   class DpuFeatureCapability(DynamicData):
      networkOffloadSupported: Optional[bool] = None
      activeStandbyModeSupported: Optional[bool] = None

   class VmwareHealthCheckFeatureCapability(DistributedVirtualSwitch.HealthCheckFeatureCapability):
      vlanMtuSupported: bool
      teamingSupported: bool

   class VspanFeatureCapability(DynamicData):
      mixedDestSupported: bool
      dvportSupported: bool
      remoteSourceSupported: bool
      remoteDestSupported: bool
      encapRemoteSourceSupported: bool
      erspanProtocolSupported: Optional[bool] = None
      mirrorNetstackSupported: Optional[bool] = None

   class MtuCapability(DynamicData):
      minMtuSupported: int
      maxMtuSupported: int

   class VspanPorts(DynamicData):
      portKey: list[str] = []
      uplinkPortName: list[str] = []
      wildcardPortConnecteeType: list[str] = []
      vlans: list[int] = []
      ipAddress: list[str] = []

   class VspanSession(DynamicData):
      key: Optional[str] = None
      name: Optional[str] = None
      description: Optional[str] = None
      enabled: bool
      sourcePortTransmitted: Optional[VspanPorts] = None
      sourcePortReceived: Optional[VspanPorts] = None
      destinationPort: Optional[VspanPorts] = None
      encapsulationVlanId: Optional[int] = None
      stripOriginalVlan: bool
      mirroredPacketLength: Optional[int] = None
      normalTrafficAllowed: bool
      sessionType: Optional[str] = None
      samplingRate: Optional[int] = None
      encapType: Optional[str] = None
      erspanId: Optional[int] = None
      erspanCOS: Optional[int] = None
      erspanGraNanosec: Optional[bool] = None
      netstack: Optional[str] = None

   class IpfixConfig(DynamicData):
      collectorIpAddress: Optional[str] = None
      collectorPort: Optional[int] = None
      observationDomainId: Optional[long] = None
      activeFlowTimeout: int
      idleFlowTimeout: Optional[int] = None
      samplingRate: int
      internalFlowsOnly: bool

   class DpuFailoverPolicy(DynamicData):
      activeUplink: list[str] = []
      standbyUplink: list[str] = []

   class NetworkOffloadConfig(DynamicData):
      dpuFailoverPolicy: Optional[DpuFailoverPolicy] = None

   class RealTimeLanAnnotation(DynamicData):
      lanAUplink: list[str] = []
      lanBUplink: list[str] = []

   class RealTimeConfig(DynamicData):
      allowed: Optional[bool] = None
      lanAnnotation: Optional[RealTimeLanAnnotation] = None

   class ConfigInfo(DistributedVirtualSwitch.ConfigInfo):
      vspanSession: list[VspanSession] = []
      pvlanConfig: list[PvlanMapEntry] = []
      maxMtu: int
      linkDiscoveryProtocolConfig: Optional[LinkDiscoveryProtocolConfig] = None
      ipfixConfig: Optional[IpfixConfig] = None
      lacpGroupConfig: list[LacpGroupConfig] = []
      lacpApiVersion: Optional[str] = None
      multicastFilteringMode: Optional[str] = None
      networkOffloadSpecId: Optional[str] = None
      networkOffloadConfig: Optional[NetworkOffloadConfig] = None
      realTimeConfig: Optional[RealTimeConfig] = None

   class ConfigSpec(DistributedVirtualSwitch.ConfigSpec):
      pvlanConfigSpec: list[PvlanConfigSpec] = []
      vspanConfigSpec: list[VspanConfigSpec] = []
      maxMtu: Optional[int] = None
      linkDiscoveryProtocolConfig: Optional[LinkDiscoveryProtocolConfig] = None
      ipfixConfig: Optional[IpfixConfig] = None
      lacpApiVersion: Optional[str] = None
      multicastFilteringMode: Optional[str] = None
      networkOffloadSpecId: Optional[str] = None
      networkOffloadConfig: Optional[NetworkOffloadConfig] = None
      realTimeConfig: Optional[RealTimeConfig] = None

   class UplinkPortOrderPolicy(InheritablePolicy):
      activeUplinkPort: list[str] = []
      standbyUplinkPort: list[str] = []

   class FailureCriteria(InheritablePolicy):
      checkSpeed: Optional[StringPolicy] = None
      speed: Optional[IntPolicy] = None
      checkDuplex: Optional[BoolPolicy] = None
      fullDuplex: Optional[BoolPolicy] = None
      checkErrorPercent: Optional[BoolPolicy] = None
      percentage: Optional[IntPolicy] = None
      checkBeacon: Optional[BoolPolicy] = None

   class UplinkPortTeamingPolicy(InheritablePolicy):
      policy: Optional[StringPolicy] = None
      reversePolicy: Optional[BoolPolicy] = None
      notifySwitches: Optional[BoolPolicy] = None
      rollingOrder: Optional[BoolPolicy] = None
      failureCriteria: Optional[FailureCriteria] = None
      uplinkPortOrder: Optional[UplinkPortOrderPolicy] = None

   class VlanSpec(InheritablePolicy):
      pass

   class PvlanSpec(VlanSpec):
      pvlanId: int

   class VlanIdSpec(VlanSpec):
      vlanId: int

   class TrunkVlanSpec(VlanSpec):
      vlanId: list[NumericRange] = []

   class SecurityPolicy(InheritablePolicy):
      allowPromiscuous: Optional[BoolPolicy] = None
      macChanges: Optional[BoolPolicy] = None
      forgedTransmits: Optional[BoolPolicy] = None

   class MacLimitPolicyType(Enum):
      allow: ClassVar['MacLimitPolicyType'] = 'allow'
      drop: ClassVar['MacLimitPolicyType'] = 'drop'

   class MacLearningPolicy(InheritablePolicy):
      enabled: bool
      allowUnicastFlooding: Optional[bool] = None
      limit: Optional[int] = None
      limitPolicy: Optional[str] = None

   class MacManagementPolicy(InheritablePolicy):
      allowPromiscuous: Optional[bool] = None
      macChanges: Optional[bool] = None
      forgedTransmits: Optional[bool] = None
      macLearningPolicy: Optional[MacLearningPolicy] = None

   class VmwarePortConfigPolicy(DistributedVirtualPort.Setting):
      vlan: Optional[VlanSpec] = None
      qosTag: Optional[IntPolicy] = None
      uplinkTeamingPolicy: Optional[UplinkPortTeamingPolicy] = None
      securityPolicy: Optional[SecurityPolicy] = None
      ipfixEnabled: Optional[BoolPolicy] = None
      txUplink: Optional[BoolPolicy] = None
      lacpPolicy: Optional[UplinkLacpPolicy] = None
      macManagementPolicy: Optional[MacManagementPolicy] = None
      VNI: Optional[IntPolicy] = None

   class VMwarePortgroupPolicy(DistributedVirtualPortgroup.PortgroupPolicy):
      vlanOverrideAllowed: bool
      uplinkTeamingOverrideAllowed: bool
      securityPolicyOverrideAllowed: bool
      ipfixOverrideAllowed: Optional[bool] = None
      macManagementOverrideAllowed: Optional[bool] = None

   class PvlanPortType(Enum):
      promiscuous: ClassVar['PvlanPortType'] = 'promiscuous'
      isolated: ClassVar['PvlanPortType'] = 'isolated'
      community: ClassVar['PvlanPortType'] = 'community'

   class PvlanConfigSpec(DynamicData):
      pvlanEntry: PvlanMapEntry
      operation: str

   class PvlanMapEntry(DynamicData):
      primaryVlanId: int
      secondaryVlanId: int
      pvlanType: str

   class VspanConfigSpec(DynamicData):
      vspanSession: VspanSession
      operation: str

   class VspanSessionEncapType(Enum):
      gre: ClassVar['VspanSessionEncapType'] = 'gre'
      erspan2: ClassVar['VspanSessionEncapType'] = 'erspan2'
      erspan3: ClassVar['VspanSessionEncapType'] = 'erspan3'

   class VspanSessionType(Enum):
      mixedDestMirror: ClassVar['VspanSessionType'] = 'mixedDestMirror'
      dvPortMirror: ClassVar['VspanSessionType'] = 'dvPortMirror'
      remoteMirrorSource: ClassVar['VspanSessionType'] = 'remoteMirrorSource'
      remoteMirrorDest: ClassVar['VspanSessionType'] = 'remoteMirrorDest'
      encapsulatedRemoteMirrorSource: ClassVar['VspanSessionType'] = 'encapsulatedRemoteMirrorSource'

   class VmwareHealthCheckConfig(DistributedVirtualSwitch.HealthCheckConfig):
      pass

   class VlanMtuHealthCheckConfig(VmwareHealthCheckConfig):
      pass

   class TeamingHealthCheckConfig(VmwareHealthCheckConfig):
      pass

   class VlanHealthCheckResult(HostMember.UplinkHealthCheckResult):
      trunkedVlan: list[NumericRange] = []
      untrunkedVlan: list[NumericRange] = []

   class MtuHealthCheckResult(HostMember.UplinkHealthCheckResult):
      mtuMismatch: bool
      vlanSupportSwitchMtu: list[NumericRange] = []
      vlanNotSupportSwitchMtu: list[NumericRange] = []

   class TeamingMatchStatus(Enum):
      iphashMatch: ClassVar['TeamingMatchStatus'] = 'iphashMatch'
      nonIphashMatch: ClassVar['TeamingMatchStatus'] = 'nonIphashMatch'
      iphashMismatch: ClassVar['TeamingMatchStatus'] = 'iphashMismatch'
      nonIphashMismatch: ClassVar['TeamingMatchStatus'] = 'nonIphashMismatch'

   class TeamingHealthCheckResult(HostMember.HealthCheckResult):
      teamingStatus: str

   class UplinkLacpPolicy(InheritablePolicy):
      enable: Optional[BoolPolicy] = None
      mode: Optional[StringPolicy] = None

   class LacpGroupConfig(DynamicData):
      key: Optional[str] = None
      name: Optional[str] = None
      mode: Optional[str] = None
      uplinkNum: Optional[int] = None
      loadbalanceAlgorithm: Optional[str] = None
      vlan: Optional[LagVlanConfig] = None
      ipfix: Optional[LagIpfixConfig] = None
      uplinkName: list[str] = []
      uplinkPortKey: list[str] = []
      timeoutMode: Optional[str] = None

   class LagVlanConfig(DynamicData):
      vlanId: list[NumericRange] = []

   class LagIpfixConfig(DynamicData):
      ipfixEnabled: Optional[bool] = None

   class UplinkLacpMode(Enum):
      active: ClassVar['UplinkLacpMode'] = 'active'
      passive: ClassVar['UplinkLacpMode'] = 'passive'

   class UplinkLacpTimeoutMode(Enum):
      fast: ClassVar['UplinkLacpTimeoutMode'] = 'fast'
      slow: ClassVar['UplinkLacpTimeoutMode'] = 'slow'

   class LacpGroupSpec(DynamicData):
      lacpGroupConfig: LacpGroupConfig
      operation: str

   class LacpLoadBalanceAlgorithm(Enum):
      srcMac: ClassVar['LacpLoadBalanceAlgorithm'] = 'srcMac'
      destMac: ClassVar['LacpLoadBalanceAlgorithm'] = 'destMac'
      srcDestMac: ClassVar['LacpLoadBalanceAlgorithm'] = 'srcDestMac'
      destIpVlan: ClassVar['LacpLoadBalanceAlgorithm'] = 'destIpVlan'
      srcIpVlan: ClassVar['LacpLoadBalanceAlgorithm'] = 'srcIpVlan'
      srcDestIpVlan: ClassVar['LacpLoadBalanceAlgorithm'] = 'srcDestIpVlan'
      destTcpUdpPort: ClassVar['LacpLoadBalanceAlgorithm'] = 'destTcpUdpPort'
      srcTcpUdpPort: ClassVar['LacpLoadBalanceAlgorithm'] = 'srcTcpUdpPort'
      srcDestTcpUdpPort: ClassVar['LacpLoadBalanceAlgorithm'] = 'srcDestTcpUdpPort'
      destIpTcpUdpPort: ClassVar['LacpLoadBalanceAlgorithm'] = 'destIpTcpUdpPort'
      srcIpTcpUdpPort: ClassVar['LacpLoadBalanceAlgorithm'] = 'srcIpTcpUdpPort'
      srcDestIpTcpUdpPort: ClassVar['LacpLoadBalanceAlgorithm'] = 'srcDestIpTcpUdpPort'
      destIpTcpUdpPortVlan: ClassVar['LacpLoadBalanceAlgorithm'] = 'destIpTcpUdpPortVlan'
      srcIpTcpUdpPortVlan: ClassVar['LacpLoadBalanceAlgorithm'] = 'srcIpTcpUdpPortVlan'
      srcDestIpTcpUdpPortVlan: ClassVar['LacpLoadBalanceAlgorithm'] = 'srcDestIpTcpUdpPortVlan'
      destIp: ClassVar['LacpLoadBalanceAlgorithm'] = 'destIp'
      srcIp: ClassVar['LacpLoadBalanceAlgorithm'] = 'srcIp'
      srcDestIp: ClassVar['LacpLoadBalanceAlgorithm'] = 'srcDestIp'
      vlan: ClassVar['LacpLoadBalanceAlgorithm'] = 'vlan'
      srcPortId: ClassVar['LacpLoadBalanceAlgorithm'] = 'srcPortId'

   class LacpApiVersion(Enum):
      singleLag: ClassVar['LacpApiVersion'] = 'singleLag'
      multipleLag: ClassVar['LacpApiVersion'] = 'multipleLag'

   class MulticastFilteringMode(Enum):
      legacyFiltering: ClassVar['MulticastFilteringMode'] = 'legacyFiltering'
      snooping: ClassVar['MulticastFilteringMode'] = 'snooping'

   def UpdateLacpGroupConfig(self, lacpGroupSpec: list[LacpGroupSpec]) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import VirtualMachine

from pyVmomi.vim.fault import ReplicationConfigFault

class ReplicationDiskConfigFault(ReplicationConfigFault):
   class ReasonForFault(Enum):
      diskNotFound: ClassVar['ReasonForFault'] = 'diskNotFound'
      diskTypeNotSupported: ClassVar['ReasonForFault'] = 'diskTypeNotSupported'
      invalidDiskKey: ClassVar['ReasonForFault'] = 'invalidDiskKey'
      invalidDiskReplicationId: ClassVar['ReasonForFault'] = 'invalidDiskReplicationId'
      duplicateDiskReplicationId: ClassVar['ReasonForFault'] = 'duplicateDiskReplicationId'
      invalidPersistentFilePath: ClassVar['ReasonForFault'] = 'invalidPersistentFilePath'
      reconfigureDiskReplicationIdNotAllowed: ClassVar['ReasonForFault'] = 'reconfigureDiskReplicationIdNotAllowed'

   reason: Optional[str] = None
   vmRef: Optional[VirtualMachine] = None
   key: Optional[int] = None



# Copyright (c) 2025 Broadcom. All Rights Reserved.
# The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.

from .five import pyMajor, pyMinor

if (pyMajor, pyMinor) < (3, 9):
    msg = "Python 3.9 or newer is required (found {0}.{1})".format(pyMajor, pyMinor)
    raise Exception(msg)



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.profile import ApplyProfileProperty
from pyVmomi.vim.profile import Policy

class ApplyProfile(DynamicData):
   enabled: bool
   policy: list[Policy] = []
   profileTypeName: Optional[str] = None
   profileVersion: Optional[str] = None
   property: list[ApplyProfileProperty] = []
   favorite: Optional[bool] = None
   toBeMerged: Optional[bool] = None
   toReplaceWith: Optional[bool] = None
   toBeDeleted: Optional[bool] = None
   copyEnableStatus: Optional[bool] = None
   hidden: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import binary
from pyVmomi.VmomiSupport import long
from pyVmomi.VmomiSupport import short

from pyVmomi.vim import LatencySensitivity
from pyVmomi.vim import ResourceAllocationInfo

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.encryption import CryptoKeyId

from pyVmomi.vim.ext import ManagedByInfo

from pyVmomi.vim.host import CpuIdInfo

from pyVmomi.vim.option import OptionValue

from pyVmomi.vim.vApp import VmConfigInfo

from pyVmomi.vim.vm import AffinityInfo
from pyVmomi.vim.vm import BootOptions
from pyVmomi.vim.vm import ConsolePreferences
from pyVmomi.vim.vm import ContentLibraryItemInfo
from pyVmomi.vim.vm import DefaultPowerOpInfo
from pyVmomi.vim.vm import FaultToleranceConfigInfo
from pyVmomi.vim.vm import FileInfo
from pyVmomi.vim.vm import FlagInfo
from pyVmomi.vim.vm import ForkConfigInfo
from pyVmomi.vim.vm import GuestIntegrityInfo
from pyVmomi.vim.vm import GuestMonitoringModeInfo
from pyVmomi.vim.vm import NetworkShaperInfo
from pyVmomi.vim.vm import ReplicationConfigSpec
from pyVmomi.vim.vm import ScheduledHardwareUpgradeInfo
from pyVmomi.vim.vm import SgxInfo
from pyVmomi.vim.vm import ToolsConfigInfo
from pyVmomi.vim.vm import VcpuConfig
from pyVmomi.vim.vm import VirtualDeviceGroups
from pyVmomi.vim.vm import VirtualDeviceSwap
from pyVmomi.vim.vm import VirtualHardware
from pyVmomi.vim.vm import VirtualNumaInfo
from pyVmomi.vim.vm import VirtualPMem

class ConfigInfo(DynamicData):
   class NpivWwnType(Enum):
      vc: ClassVar['NpivWwnType'] = 'vc'
      host: ClassVar['NpivWwnType'] = 'host'
      external: ClassVar['NpivWwnType'] = 'external'

   class SwapPlacementType(Enum):
      inherit: ClassVar['SwapPlacementType'] = 'inherit'
      vmDirectory: ClassVar['SwapPlacementType'] = 'vmDirectory'
      hostLocal: ClassVar['SwapPlacementType'] = 'hostLocal'

   class DatastoreUrlPair(DynamicData):
      name: str
      url: str

   class OverheadInfo(DynamicData):
      initialMemoryReservation: Optional[long] = None
      initialSwapReservation: Optional[long] = None

   changeVersion: str
   modified: datetime
   name: str
   guestFullName: str
   version: str
   uuid: str
   createDate: Optional[datetime] = None
   instanceUuid: Optional[str] = None
   npivNodeWorldWideName: list[long] = []
   npivPortWorldWideName: list[long] = []
   npivWorldWideNameType: Optional[str] = None
   npivDesiredNodeWwns: Optional[short] = None
   npivDesiredPortWwns: Optional[short] = None
   npivTemporaryDisabled: Optional[bool] = None
   npivOnNonRdmDisks: Optional[bool] = None
   locationId: Optional[str] = None
   template: bool
   guestId: str
   alternateGuestName: str
   annotation: Optional[str] = None
   files: FileInfo
   tools: Optional[ToolsConfigInfo] = None
   flags: FlagInfo
   consolePreferences: Optional[ConsolePreferences] = None
   defaultPowerOps: DefaultPowerOpInfo
   rebootPowerOff: Optional[bool] = None
   hardware: VirtualHardware
   vcpuConfig: list[VcpuConfig] = []
   cpuAllocation: Optional[ResourceAllocationInfo] = None
   memoryAllocation: Optional[ResourceAllocationInfo] = None
   latencySensitivity: Optional[LatencySensitivity] = None
   memoryHotAddEnabled: Optional[bool] = None
   cpuHotAddEnabled: Optional[bool] = None
   cpuHotRemoveEnabled: Optional[bool] = None
   hotPlugMemoryLimit: Optional[long] = None
   hotPlugMemoryIncrementSize: Optional[long] = None
   cpuAffinity: Optional[AffinityInfo] = None
   memoryAffinity: Optional[AffinityInfo] = None
   networkShaper: Optional[NetworkShaperInfo] = None
   extraConfig: list[OptionValue] = []
   cpuFeatureMask: list[CpuIdInfo] = []
   datastoreUrl: list[DatastoreUrlPair] = []
   swapPlacement: Optional[str] = None
   bootOptions: Optional[BootOptions] = None
   ftInfo: Optional[FaultToleranceConfigInfo] = None
   repConfig: Optional[ReplicationConfigSpec] = None
   vAppConfig: Optional[VmConfigInfo] = None
   vAssertsEnabled: Optional[bool] = None
   changeTrackingEnabled: Optional[bool] = None
   firmware: Optional[str] = None
   maxMksConnections: Optional[int] = None
   guestAutoLockEnabled: Optional[bool] = None
   managedBy: Optional[ManagedByInfo] = None
   memoryReservationLockedToMax: Optional[bool] = None
   initialOverhead: Optional[OverheadInfo] = None
   nestedHVEnabled: Optional[bool] = None
   vPMCEnabled: Optional[bool] = None
   scheduledHardwareUpgradeInfo: Optional[ScheduledHardwareUpgradeInfo] = None
   forkConfigInfo: Optional[ForkConfigInfo] = None
   vFlashCacheReservation: Optional[long] = None
   vmxConfigChecksum: Optional[binary] = None
   messageBusTunnelEnabled: Optional[bool] = None
   vmStorageObjectId: Optional[str] = None
   swapStorageObjectId: Optional[str] = None
   keyId: Optional[CryptoKeyId] = None
   guestIntegrityInfo: Optional[GuestIntegrityInfo] = None
   migrateEncryption: Optional[str] = None
   sgxInfo: Optional[SgxInfo] = None
   contentLibItemInfo: Optional[ContentLibraryItemInfo] = None
   ftEncryptionMode: Optional[str] = None
   guestMonitoringModeInfo: Optional[GuestMonitoringModeInfo] = None
   sevEnabled: Optional[bool] = None
   numaInfo: Optional[VirtualNumaInfo] = None
   pmemFailoverEnabled: Optional[bool] = None
   vmxStatsCollectionEnabled: Optional[bool] = None
   vmOpNotificationToAppEnabled: Optional[bool] = None
   vmOpNotificationTimeout: Optional[long] = None
   deviceSwap: Optional[VirtualDeviceSwap] = None
   pmem: Optional[VirtualPMem] = None
   deviceGroups: Optional[VirtualDeviceGroups] = None
   fixedPassthruHotPlugEnabled: Optional[bool] = None
   metroFtEnabled: Optional[bool] = None
   vmxRuntimeConfig: list[OptionValue] = []
   metroFtHostGroup: Optional[str] = None
   tdxEnabled: Optional[bool] = None
   sevSnpEnabled: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .AfterStartupTaskScheduler import AfterStartupTaskScheduler as AfterStartupTaskScheduler
from .DailyTaskScheduler import DailyTaskScheduler as DailyTaskScheduler
from .HourlyTaskScheduler import HourlyTaskScheduler as HourlyTaskScheduler
from .MonthlyByDayTaskScheduler import MonthlyByDayTaskScheduler as MonthlyByDayTaskScheduler
from .MonthlyByWeekdayTaskScheduler import MonthlyByWeekdayTaskScheduler as MonthlyByWeekdayTaskScheduler
from .MonthlyTaskScheduler import MonthlyTaskScheduler as MonthlyTaskScheduler
from .OnceTaskScheduler import OnceTaskScheduler as OnceTaskScheduler
from .RecurrentTaskScheduler import RecurrentTaskScheduler as RecurrentTaskScheduler
from .ScheduledTask import ScheduledTask as ScheduledTask
from .ScheduledTaskDescription import ScheduledTaskDescription as ScheduledTaskDescription
from .ScheduledTaskInfo import ScheduledTaskInfo as ScheduledTaskInfo
from .ScheduledTaskManager import ScheduledTaskManager as ScheduledTaskManager
from .ScheduledTaskSpec import ScheduledTaskSpec as ScheduledTaskSpec
from .TaskScheduler import TaskScheduler as TaskScheduler
from .WeeklyTaskScheduler import WeeklyTaskScheduler as WeeklyTaskScheduler



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import HardwareStatusInfo
from pyVmomi.vim.host import SystemEventInfo
from pyVmomi.vim.host import SystemHealthInfo

class HealthStatusSystem(ManagedObject):
   class Runtime(DynamicData):
      systemHealthInfo: Optional[SystemHealthInfo] = None
      hardwareStatusInfo: Optional[HardwareStatusInfo] = None

   @property
   def runtime(self) -> Runtime: ...

   def Refresh(self) -> NoReturn: ...
   def ResetSystemHealthInfo(self) -> NoReturn: ...
   def ClearSystemEventLog(self) -> NoReturn: ...
   def FetchSystemEventLog(self) -> list[SystemEventInfo]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from pyVmomi.vim import ManagedEntity

from pyVmomi.vim.alarm import Alarm
from pyVmomi.vim.alarm import AlarmSpec

class AlarmInfo(AlarmSpec):
   key: str
   alarm: Alarm
   entity: ManagedEntity
   lastModifiedTime: datetime
   lastModifiedUser: str
   creationEventId: int



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.vm import TargetInfo

class ScsiPassthroughInfo(TargetInfo):
   class ScsiClass(Enum):
      disk: ClassVar['ScsiClass'] = 'disk'
      tape: ClassVar['ScsiClass'] = 'tape'
      printer: ClassVar['ScsiClass'] = 'printer'
      processor: ClassVar['ScsiClass'] = 'processor'
      worm: ClassVar['ScsiClass'] = 'worm'
      cdrom: ClassVar['ScsiClass'] = 'cdrom'
      scanner: ClassVar['ScsiClass'] = 'scanner'
      optical: ClassVar['ScsiClass'] = 'optical'
      media: ClassVar['ScsiClass'] = 'media'
      com: ClassVar['ScsiClass'] = 'com'
      raid: ClassVar['ScsiClass'] = 'raid'
      unknown: ClassVar['ScsiClass'] = 'unknown'

   scsiClass: str
   vendor: str
   physicalUnitNumber: int



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import HostSystem
from pyVmomi.vim import Task

class CertificateManager(ManagedObject):
   def RefreshCACertificatesAndCRLs(self, host: list[HostSystem]) -> Task: ...
   def RefreshCertificates(self, host: list[HostSystem]) -> Task: ...
   def RevokeCertificates(self, host: list[HostSystem]) -> Task: ...
